pub struct Pool(/* private fields */);Expand description
A Pool object represents a private thread pool with its own thread limits.
This is in contrast to the default, or shared, thread pool used by the crate’s submit function
as well as other code within the same process.
Implementations